@@ -1,7 +1,7 @@
 
 package OODoc::Text::Structure;
-use vars 'VERSION';
-$VERSION = '0.03';
+use vars '$VERSION';
+$VERSION = '0.04';
 use base 'OODoc::Text';
 
 use strict;
@@ -21,11 +21,44 @@ sub init($)
 {   my ($self, $args) = @_;
     $self->SUPER::init($args) or return;
     $self->{OTS_subs} = [];
+    $self->{OTS_level} = delete $args->{level}
+        or croak "ERROR: no level defined for structural component";
+
+    $self;
 }
 
 #-------------------------------------------
 
 
+sub emptyExtension($)
+{   my ($self, $container) = @_;
+
+    my $new = ref($self)->new
+     ( name      => $self->name
+     , linenr    => -1
+     , level     => $self->level
+     , container => $container
+     );
+   $new->extends($self);
+   $new;
+}
+
+#-------------------------------------------
+
+
+#-------------------------------------------
+
+
+sub level() {shift->{OTS_level}}
+
+#-------------------------------------------
+
+
+sub niceName()
+{   my $name = shift->name;
+    $name =~ m/[a-z]/ ? $name : ucfirst(lc $name);
+}
+
 #-------------------------------------------
 
 
@@ -48,6 +81,7 @@ sub all($@)
 sub addSubroutine(@)
 {  my $self = shift;
    push @{$self->{OTS_subs}}, @_;
+   $_->container($self) for @_;
    $self;
 }
 
@@ -59,14 +93,6 @@ sub subroutines() { @{shift->{OTS_subs}} }
 #-------------------------------------------
 
 
-sub setSubroutines()
-{   my $self = shift;
-    $self->{OTS_subs} = [ @_ ];
-}
-
-#-------------------------------------------
-
-
 sub subroutine($)
 {   my ($self, $name) = @_;
     first {$_->name eq $name} $self->subroutines;
@@ -74,4 +100,14 @@ sub subroutine($)
 
 #-------------------------------------------
 
+
+sub setSubroutines($)
+{   my $self = shift;
+    $self->{OTS_subs} = shift || [];
+}
+
+#-------------------------------------------
+
+
+
 1;
